Discover Packages
github.com/edlundin/enocean-esp3
internal
eepgen
package
Version:
v0.0.0-...-7f16780
Opens a new window with list of versions in this module.
Published: Jul 15, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 13
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
Generate generates Go profile metadata from EEP XML.
type Case struct {
Fields []Field `xml:"datafield"`
}
type EEP struct {
Rorgs []Rorg `xml:"profile>rorg"`
DirectRorgs []Rorg `xml:"rorg"`
}
LoadRaw loads the raw EEP XML model.
type Enum struct {
Items []EnumItem `xml:"item"`
}
type EnumItem struct {
Value string `xml:"value"`
Min string `xml:"min"`
Max string `xml:"max"`
Unit string `xml:"unit"`
Description string `xml:"description"`
Scales []Scale `xml:"scale"`
}
type Field struct {
Data string `xml:"data"`
Shortcut string `xml:"shortcut"`
Description string `xml:"description"`
BitOff string `xml:"bitoffs"`
BitSize string `xml:"bitsize"`
Unit string `xml:"unit"`
Enums []Enum `xml:"enum"`
Ranges []Range `xml:"range"`
Scales []Scale `xml:"scale"`
}
type Func struct {
Number string `xml:"number"`
Title string `xml:"title"`
Types []Type `xml:"type"`
}
type OutProfile struct {
Key, Rorg, Func, Type, Title string
Fields []OutField
}
Load loads EEP profiles from XML.
type Range struct {
Min string `xml:"min"`
Max string `xml:"max"`
}
type Rorg struct {
Number string `xml:"number"`
Title string `xml:"title"`
Funcs []Func `xml:"func"`
}
type Scale struct {
Min string `xml:"min"`
Max string `xml:"max"`
}
type Type struct {
Number string `xml:"number"`
Title string `xml:"title"`
Cases []Case `xml:"case"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.